.. _spkg_snappy:

snappy: Topology and geometry of 3-manifolds, with a focus on hyperbolic structures
=============================================================================================

Description
-----------

Studying the topology and geometry of 3-manifolds, with a focus on hyperbolic structures.

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/snappy/


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_decorator`
- :ref:`spkg_ipython`
- sagelib
- :ref:`spkg_sagemath_pari`

Version Information
-------------------

requirements.txt::

    snappy
    cypari !=2.4.0
    snappy_15_knots


Equivalent System Packages
--------------------------

(none known)

